@@ -21,8 +21,8 @@ import time
 from six.moves import queue as Queue
 
 from rally.common import utils
+from rally.common import validation
 from rally import consts
-from rally import exceptions
 from rally.task import runner
 from rally.task import utils as butils
 
@@ -116,6 +116,21 @@ def _worker_process(queue, iteration_gen, timeout, concurrency, times,
         collector_thr_by_timeout.join()
 
 
+@validation.configure("check_constant")
+class CheckConstantValidator(validation.Validator):
+    """Additional schema validation for constant runner"""
+
+    def validate(self, context, config, plugin_cls, plugin_cfg):
+        if plugin_cfg.get("concurrency", 1) > plugin_cfg.get("times", 1):
+            return self.fail(
+                "Parameter 'concurrency' means a number of parallel executions"
+                "of iterations. Parameter 'times' means total number of "
+                "iteration executions. It is redundant (and restricted) to "
+                "have number of parallel iterations bigger then total number "
+                "of iterations.")
+
+
+@validation.add("check_constant")
 @runner.configure(name="constant")
 class ConstantScenarioRunner(runner.ScenarioRunner):
     """Creates constant load executing a scenario a specified number of times.
@@ -134,10 +149,6 @@ class ConstantScenarioRunner(runner.ScenarioRunner):
         "type": "object",
         "$schema": consts.JSON_SCHEMA,
         "properties": {
-            "type": {
-                "type": "string",
-                "description": "Type of Runner."
-            },
             "concurrency": {
                 "type": "integer",
                 "minimum": 1,
@@ -159,24 +170,11 @@ class ConstantScenarioRunner(runner.ScenarioRunner):
                                " from."
             }
         },
-        "required": ["type"],
         "additionalProperties": False
     }
 
-    @classmethod
-    def validate(cls, config):
-        """Validates runner's part of task config."""
-        super(ConstantScenarioRunner, cls).validate(config)
-        if config.get("concurrency", 1) > config.get("times", 1):
-            raise exceptions.ValidationError(
-                "Parameter 'concurrency' means a number of parallel executions"
-                "of iterations. Parameter 'times' means total number of "
-                "iteration executions. It is redundant (and restricted) to "
-                "have number of parallel iterations bigger then total number "
-                "of iterations.")
-
     def _run_scenario(self, cls, method_name, context, args):
-        """Runs the specified benchmark scenario with given arguments.
+        """Runs the specified scenario with given arguments.
 
         This method generates a constant load on the cloud under test by
         executing each scenario iteration using a pool of processes without
@@ -185,8 +183,9 @@ class ConstantScenarioRunner(runner.ScenarioRunner):
 
         :param cls: The Scenario class where the scenario is implemented
         :param method_name: Name of the method that implements the scenario
-        :param context: Benchmark context that contains users, admin & other
-                        information, that was created before benchmark started.
+        :param context: context that contains users, admin & other
+                        information, that was created before scenario
+                        execution starts.
         :param args: Arguments to call the scenario method with
 
         :returns: List of results fore each single scenario iteration,
@@ -259,10 +258,6 @@ class ConstantForDurationScenarioRunner(runner.ScenarioRunner):
         "type": "object",
         "$schema": consts.JSON_SCHEMA,
         "properties": {
-            "type": {
-                "type": "string",
-                "description": "Type of Runner."
-            },
             "concurrency": {
                 "type": "integer",
                 "minimum": 1,
@@ -280,7 +275,7 @@ class ConstantForDurationScenarioRunner(runner.ScenarioRunner):
                 "description": "Operation's timeout."
             }
         },
-        "required": ["type", "duration"],
+        "required": ["duration"],
         "additionalProperties": False
     }
 
@@ -294,12 +289,13 @@ class ConstantForDurationScenarioRunner(runner.ScenarioRunner):
         return _scenario_args
 
     def _run_scenario(self, cls, method, context, args):
-        """Runs the specified benchmark scenario with given arguments.
+        """Runs the specified scenario with given arguments.
 
         :param cls: The Scenario class where the scenario is implemented
         :param method: Name of the method that implements the scenario
-        :param context: Benchmark context that contains users, admin & other
-                        information, that was created before benchmark started.
+        :param context: context that contains users, admin & other
+                        information, that was created before scenario is
+                        execution starts.
         :param args: Arguments to call the scenario method with
 
         :returns: List of results fore each single scenario iteration,
