@@ -13,11 +13,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from rally.common.i18n import _
 from rally.common import logging
 from rally.common import utils
+from rally.common import validation
 from rally import consts
-from rally import osclients
+from rally.plugins.openstack import osclients
 from rally.plugins.openstack.wrappers import network as network_wrapper
 from rally.task import context
 
@@ -25,7 +25,10 @@ from rally.task import context
 LOG = logging.getLogger(__name__)
 
 
-@context.configure(name="network", order=350)
+# NOTE(andreykurilin): admin is used only by cleanup
+@validation.add("required_platform", platform="openstack", admin=True,
+                users=True)
+@context.configure(name="network", platform="openstack", order=350)
 class Network(context.Context):
     """Create networking resources.
 
@@ -56,6 +59,24 @@ class Network(context.Context):
                 "type": "array",
                 "items": {"type": "string"},
                 "uniqueItems": True
+            },
+            "router": {
+                "type": "object",
+                "properties": {
+                    "external": {
+                        "type": "boolean"
+                    },
+                    "external_gateway_info": {
+                        "description": "The external gateway information .",
+                        "type": "object",
+                        "properties": {
+                            "network_id": {"type": "string"},
+                            "enable_snat": {"type": "boolean"}
+                        },
+                        "additionalProperties": False
+                    }
+                },
+                "additionalProperties": False
             }
         },
         "additionalProperties": False
@@ -66,10 +87,10 @@ class Network(context.Context):
         "networks_per_tenant": 1,
         "subnets_per_network": 1,
         "network_create_args": {},
-        "dns_nameservers": None
+        "dns_nameservers": None,
+        "router": {"external": True}
     }
 
-    @logging.log_task_wrapper(LOG.info, _("Enter context: `network`"))
     def setup(self):
         # NOTE(rkiran): Some clients are not thread-safe. Thus during
         #               multithreading/multiprocessing, it is likely the
@@ -90,13 +111,12 @@ class Network(context.Context):
                 network_create_args = self.config["network_create_args"].copy()
                 network = net_wrapper.create_network(
                     tenant_id,
-                    add_router=True,
                     subnets_num=self.config["subnets_per_network"],
                     network_create_args=network_create_args,
+                    router_create_args=self.config["router"],
                     **kwargs)
                 self.context["tenants"][tenant_id]["networks"].append(network)
 
-    @logging.log_task_wrapper(LOG.info, _("Exit context: `network`"))
     def cleanup(self):
         net_wrapper = network_wrapper.wrap(
             osclients.Clients(self.context["admin"]["credential"]),
@@ -105,6 +125,5 @@ class Network(context.Context):
             for network in tenant_ctx.get("networks", []):
                 with logging.ExceptionLogger(
                         LOG,
-                        _("Failed to delete network for tenant %s")
-                        % tenant_id):
+                        "Failed to delete network for tenant %s" % tenant_id):
                     net_wrapper.delete_network(network)
