@@ -13,8 +13,7 @@
 # under the License.
 
 
-from oslo_config import cfg
-
+from rally.common import cfg
 from rally.plugins.openstack import scenario
 from rally.task import atomic
 from rally.task import utils
