@@ -22,8 +22,8 @@ from rally.plugins.openstack.scenarios.zaqar import utils as zutils
 """Scenarios for Zaqar."""
 
 
-@scenario.configure(context={"cleanup": ["zaqar"]},
-                    name="ZaqarBasic.create_queue")
+@scenario.configure(context={"cleanup@openstack": ["zaqar"]},
+                    name="ZaqarBasic.create_queue", platform="openstack")
 class CreateQueue(zutils.ZaqarScenario):
 
     @logging.log_deprecated_args(
@@ -38,8 +38,8 @@ class CreateQueue(zutils.ZaqarScenario):
         self._queue_create(**kwargs)
 
 
-@scenario.configure(context={"cleanup": ["zaqar"]},
-                    name="ZaqarBasic.producer_consumer")
+@scenario.configure(context={"cleanup@openstack": ["zaqar"]},
+                    name="ZaqarBasic.producer_consumer", platform="openstack")
 class ProducerConsumer(zutils.ZaqarScenario):
 
     @logging.log_deprecated_args(
