@@ -18,6 +18,7 @@ import abc
 import netaddr
 import six
 
+from rally.common import cfg
 from rally.common import logging
 from rally.common import utils
 from rally import consts
@@ -27,6 +28,7 @@ from neutronclient.common import exceptions as neutron_exceptions
 
 
 LOG = logging.getLogger(__name__)
+CONF = cfg.CONF
 
 
 cidr_incr = utils.RAMInt()
@@ -194,12 +196,14 @@ class NeutronWrapper(NetworkWrapper):
 
         The following keyword arguments are accepted:
 
-        * add_router: Create an external router and add an interface to each
+        * add_router: Deprecated, please use router_create_args instead.
+                      Create an external router and add an interface to each
                       subnet created. Default: False
         * subnets_num: Number of subnets to create per network. Default: 0
         * dns_nameservers: Nameservers for each subnet. Default:
                            8.8.8.8, 8.8.4.4
         * network_create_args: Additional network creation arguments.
+        * router_create_args: Additional router creation arguments.
 
         :param tenant_id: str, tenant ID
         :param kwargs: Additional options, left open-ended for compatbilitiy.
@@ -213,8 +217,13 @@ class NeutronWrapper(NetworkWrapper):
         network = self.client.create_network(network_args)["network"]
 
         router = None
-        if kwargs.get("add_router", False):
-            router = self.create_router(external=True, tenant_id=tenant_id)
+        router_args = dict(kwargs.get("router_create_args", {}))
+        add_router = kwargs.get("add_router", False)
+        if router_args or add_router:
+            router_args["external"] = (
+                router_args.get("external", False) or add_router)
+            router_args["tenant_id"] = tenant_id
+            router = self.create_router(**router_args)
 
         subnets = []
         subnets_num = kwargs.get("subnets_num", 0)
@@ -328,7 +337,6 @@ class NeutronWrapper(NetworkWrapper):
         if not tenant_id:
             raise ValueError("Missed tenant_id")
 
-        net_id = None
         if type(ext_network) is dict:
             net_id = ext_network["id"]
         elif ext_network:
@@ -347,6 +355,11 @@ class NeutronWrapper(NetworkWrapper):
 
         kwargs = {"floatingip": {"floating_network_id": net_id,
                                  "tenant_id": tenant_id}}
+
+        if not CONF.openstack.pre_newton_neutron:
+            descr = self.owner.generate_random_name()
+            kwargs["floatingip"]["description"] = descr
+
         if port_id:
             kwargs["floatingip"]["port_id"] = port_id
 
