@@ -18,16 +18,16 @@
 
 import argparse
 import json
+import os
 import subprocess
 import sys
 
 import six
 
 from rally.cli import cliutils
-from rally.common import objects
 from rally.common.plugin import discover
 from rally import consts
-from rally import osclients
+from rally.plugins.openstack import credential
 
 
 def skip_if_service(service):
@@ -66,7 +66,6 @@ class ResourceManager(object):
             f = getattr(self, prop)
             resources = f() or []
             resource_name = prop[5:][:-1]
-
             for raw_res in resources:
                 res = {"cls": cls, "resource_name": resource_name,
                        "id": {}, "props": {}}
@@ -85,6 +84,9 @@ class ResourceManager(object):
                         except TypeError:
                             res["props"][key] = str(value)
                 if not res["id"] and not res["props"]:
+                    print("1: %s" % raw_res)
+                    print("2: %s" % cls)
+                    print("3: %s" % resource_name)
                     raise ValueError("Failed to represent resource %r" %
                                      raw_res)
                 all_resources.append(res)
@@ -163,18 +165,6 @@ class Nova(ResourceManager):
     def list_flavors(self):
         return self.client.flavors.list()
 
-    @skip_if_service(consts.Service.NEUTRON)
-    def list_floating_ip_pools(self):
-        return self.client.floating_ip_pools.list()
-
-    @skip_if_service(consts.Service.NEUTRON)
-    def list_floating_ips(self):
-        return self.client.floating_ips.list()
-
-    @skip_if_service(consts.Service.NEUTRON)
-    def list_floating_ips_bulk(self):
-        return self.client.floating_ips_bulk.list()
-
     def list_aggregates(self):
         return self.client.aggregates.list()
 
@@ -190,19 +180,13 @@ class Nova(ResourceManager):
     def list_keypairs(self):
         return self.client.keypairs.list()
 
-    @skip_if_service(consts.Service.NEUTRON)
-    def list_networks(self):
-        return self.client.networks.list()
-
-    @skip_if_service(consts.Service.NEUTRON)
-    def list_security_groups(self):
-        return self.client.security_groups.list(
-            search_opts={"all_tenants": True})
-
     def list_servers(self):
         return self.client.servers.list(
             search_opts={"all_tenants": True})
 
+    def list_server_groups(self):
+        return self.client.server_groups.list(all_projects=True)
+
     def list_services(self):
         return self.client.services.list()
 
@@ -248,6 +232,10 @@ class Neutron(ResourceManager):
         if self.has_extension("lbaas"):
             return self.client.list_vips()["vips"]
 
+    def list_bgpvpns(self):
+        if self.has_extension("bgpvpn"):
+            return self.client.list_bgpvpns()["bgpvpns"]
+
 
 class Glance(ResourceManager):
 
@@ -291,10 +279,10 @@ class Cinder(ResourceManager):
         return self.client.transfers.list()
 
     def list_volumes(self):
-        # ignore cache volumes for images
-        volumes = self.client.volumes.list(search_opts={"all_tenants": True})
-        return [v for v in volumes
-                if not v.name.startswith("image-")]
+        return self.client.volumes.list(search_opts={"all_tenants": True})
+
+    def list_qos(self):
+        return self.client.qos_specs.list()
 
 
 class Senlin(ResourceManager):
@@ -308,6 +296,119 @@ class Senlin(ResourceManager):
         return self.client.profiles()
 
 
+class Manila(ResourceManager):
+
+    REQUIRED_SERVICE = consts.Service.MANILA
+
+    def list_shares(self):
+        return self.client.shares.list(detailed=False,
+                                       search_opts={"all_tenants": True})
+
+    def list_share_networks(self):
+        return self.client.share_networks.list(
+            detailed=False, search_opts={"all_tenants": True})
+
+    def list_share_servers(self):
+        return self.client.share_servers.list(
+            search_opts={"all_tenants": True})
+
+
+class Gnocchi(ResourceManager):
+
+    REQUIRED_SERVICE = consts.Service.GNOCCHI
+
+    def list_resources(self):
+        return self.client.resource.list()
+
+
+class Ironic(ResourceManager):
+
+    REQUIRED_SERVICE = consts.Service.IRONIC
+
+    def list_nodes(self):
+        return self.client.node.list()
+
+
+class Sahara(ResourceManager):
+
+    REQUIRED_SERVICE = consts.Service.SAHARA
+
+    def list_node_group_templates(self):
+        return self.client.node_group_templates.list()
+
+
+class Murano(ResourceManager):
+
+    REQUIRED_SERVICE = consts.Service.MURANO
+
+    def list_environments(self):
+        return self.client.environments.list()
+
+    def list_packages(self):
+        return self.client.packages.list(include_disabled=True)
+
+
+class Designate(ResourceManager):
+
+    REQUIRED_SERVICE = consts.Service.DESIGNATE
+
+    def list_domains(self):
+        return self.client.domains.list()
+
+    def list_records(self):
+        result = []
+        result.extend(self.client.records.list(domain_id)
+                      for domain_id in self.client.domains.list())
+        return result
+
+    def list_servers(self):
+        return self.client.servers.list()
+
+    def list_zones(self):
+        return self.clients.designate("2").zones.list()
+
+    def list_recordset(self):
+        client = self.clients.designate("2")
+        results = []
+        results.extend(client.recordsets.list(zone_id)
+                       for zone_id in client.zones.list())
+        return results
+
+
+class Trove(ResourceManager):
+
+    REQUIRED_SERVICE = consts.Service.TROVE
+
+    def list_backups(self):
+        return self.client.backup.list()
+
+    def list_clusters(self):
+        return self.client.cluster.list()
+
+    def list_configurations(self):
+        return self.client.configuration.list()
+
+    def list_databases(self):
+        return self.client.database.list()
+
+    def list_datastore(self):
+        return self.client.datastore.list()
+
+    def list_instances(self):
+        return self.client.list(include_clustered=True)
+
+    def list_modules(self):
+        return self.client.module.list(datastore="all")
+
+
+class Monasca(ResourceManager):
+
+    REQUIRED_SERVICE = consts.Service.MONASCA
+
+    def list_metrics(self):
+        return self.client.metrics.list()
+
+
 class Watcher(ResourceManager):
 
     REQUIRED_SERVICE = consts.Service.WATCHER
@@ -344,7 +445,7 @@ class CloudResources(object):
     """
 
     def __init__(self, **kwargs):
-        self.clients = osclients.Clients(objects.Credential(**kwargs))
+        self.clients = credential.OpenStackCredential(**kwargs).clients()
 
     def list(self):
         managers_classes = discover.itersubclasses(ResourceManager)
@@ -412,11 +513,11 @@ def main():
     if args.credentials:
         config = json.load(args.credentials)
     else:
-        out = subprocess.check_output(["rally", "deployment",
-                                       "config"])
+        out = subprocess.check_output(["rally", "deployment", "config",
+                                       "--deployment", "devstack"])
         config = json.loads(out if six.PY2 else out.decode("utf-8"))
+        config = config["openstack"]
         config.update(config.pop("admin"))
-        del config["type"]
         if "users" in config:
             del config["users"]
 
@@ -430,16 +531,34 @@ def main():
         changes = resources.compare(with_list=given_list)
         removed, added = changes
 
+        # Cinder has a feature - cache images for speeding-up time of creating
+        # volumes from images. let's put such cache-volumes into expected list
+        volume_names = [
+            "image-%s" % i["id"]["id"] for i in given_list
+            if i["cls"] == "glance" and i["resource_name"] == "image"]
+
         # filter out expected additions
         expected = []
         for resource in added:
-            if ((resource["cls"] == "keystone" and
-                 resource["resource_name"] == "role" and
-                 resource["id"].get("name") == "_member_") or
-                (resource["cls"] == "nova" and
-                 resource["resource_name"] == "security_group" and
-                 resource["id"].get("name") == "default")):
+            if (
+                    (resource["cls"] == "keystone" and
+                     resource["resource_name"] == "role" and
+                     resource["id"].get("name") == "_member_") or
+
+                    (resource["cls"] == "neutron" and
+                     resource["resource_name"] == "security_group" and
+                     resource["id"].get("name") == "default") or
+
+                    (resource["cls"] == "cinder" and
+                     resource["resource_name"] == "volume" and
+                     resource["id"].get("name") in volume_names) or
+
+                    resource["cls"] == "murano" or
+
+                    # Glance has issues with uWSGI integration...
+                    resource["cls"] == "glance"):
                 expected.append(resource)
+
         for resource in expected:
             added.remove(resource)
 
@@ -453,7 +572,14 @@ def main():
             _print_tabular_resources(expected, "Added resources (expected)")
 
         if any(changes):
-            return 0  # `1' will fail gate job
+            # NOTE(andreykurilin): '1' return value will fail gate job. It is
+            #     ok for changes to Rally project, but changes to other
+            #     projects, which have rally job, should not be affected by
+            #     this check, since in most cases resources are left due
+            #     to wrong cleanup of a particular scenario.
+            if os.environ.get("ZUUL_PROJECT") == "openstack/rally":
+                return 1
+            return 0
     return 0
 
 
