@@ -38,8 +38,11 @@ class TaskTestCase(unittest.TestCase):
                 {
                     "runner": {
                         "type": "constant",
-                        "times": 100,
+                        "times": 20,
                         "concurrency": 5
+                    },
+                    "sla": {
+                        "failure_rate": {"max": 100}
                     }
                 }
             ]
@@ -123,6 +126,9 @@ class TaskTestCase(unittest.TestCase):
                         "type": "constant",
                         "times": 1,
                         "concurrency": 1
+                    },
+                    "sla": {
+                        "failure_rate": {"max": 100}
                     }
                 }
             ]
@@ -180,17 +186,15 @@ class TaskTestCase(unittest.TestCase):
         rally("task start --task %s" % config.filename)
         json_report = rally.gen_report_path(extension="json")
         with open(json_report, "w+") as f:
-            f.write(rally("task results"))
+            f.write(rally("task results", no_logs=True))
         import_print = rally("task import --file %s" % json_report)
-        self.assertIn("successfully", import_print)
         task_uuid = re.search("UUID:\s([a-z0-9\-]+)", import_print).group(1)
         self.assertIn("Dummy.dummy_random_fail_in_atomic",
                       rally("task results --uuid %s" % task_uuid))
 
         # new json report
-        rally("task report --json --out %s" % json_report)
+        rally("task report --json --out %s" % json_report, no_logs=True)
         import_print = rally("task import --file %s" % json_report)
-        self.assertIn("successfully", import_print)
         task_uuid = re.search("UUID:\s([a-z0-9\-]+)", import_print).group(1)
         self.assertIn("Dummy.dummy_random_fail_in_atomic",
                       rally("task report --uuid %s --json" % task_uuid))
@@ -240,44 +244,18 @@ class TaskTestCase(unittest.TestCase):
         self.assertEqual(expected, result_embedded)
         self.assertEqual(not expected, result_external)
 
-    def test_report_one_uuid(self):
-        rally = utils.Rally()
-        cfg = self._get_sample_task_config()
-        config = utils.TaskConfig(cfg)
-        rally("task start --task %s" % config.filename)
-        html_report = rally.gen_report_path(extension="html")
-        rally("task report --out %s" % html_report)
-        self.assertTrue(os.path.exists(html_report))
-        self._assert_html_report_libs_are_embedded(html_report, False)
-        self.assertRaises(utils.RallyCliError,
-                          rally, "task report --report %s" % FAKE_TASK_UUID)
-
     def test_new_report_one_uuid(self):
         rally = utils.Rally()
         cfg = self._get_sample_task_config()
         config = utils.TaskConfig(cfg)
         rally("task start --task %s" % config.filename)
         html_report = rally.gen_report_path(extension="html")
-        rally("task report --out %s" % html_report)
+        rally("task report --out %s" % html_report, no_logs=True)
         self.assertTrue(os.path.exists(html_report))
         self._assert_html_report_libs_are_embedded(html_report, False)
         self.assertRaises(utils.RallyCliError,
                           rally, "task report --report %s" % FAKE_TASK_UUID)
 
-    def test_report_bunch_uuids(self):
-        rally = utils.Rally()
-        cfg = self._get_sample_task_config()
-        config = utils.TaskConfig(cfg)
-        task_uuids = []
-        for i in range(3):
-            res = rally("task start --task %s" % config.filename)
-            task_uuids.append(self._get_task_uuid(res))
-        html_report = rally.gen_report_path(extension="html")
-        rally("task report --tasks %s --out %s" % (" ".join(task_uuids),
-                                                   html_report))
-        self.assertTrue(os.path.exists(html_report))
-        self._assert_html_report_libs_are_embedded(html_report, False)
-
     def test_new_report_bunch_uuids(self):
         rally = utils.Rally()
         cfg = self._get_sample_task_config()
@@ -291,7 +269,7 @@ class TaskTestCase(unittest.TestCase):
                                                   html_report))
         self.assertTrue(os.path.exists(html_report))
 
-    def test_report_bunch_files(self):
+    def test_new_report_bunch_files(self):
         rally = utils.Rally()
         cfg = self._get_sample_task_config()
         config = utils.TaskConfig(cfg)
@@ -302,15 +280,15 @@ class TaskTestCase(unittest.TestCase):
             files.append(path)
             if os.path.exists(path):
                 os.remove(path)
-            rally("task results", report_path=path, raw=True)
+            rally("task results", report_path=path, raw=True, no_logs=True)
 
         html_report = rally.gen_report_path(extension="html")
-        rally("task report --tasks %s --out %s" % (
+        rally("task report --uuid %s --out %s" % (
               " ".join(files), html_report))
         self.assertTrue(os.path.exists(html_report))
         self._assert_html_report_libs_are_embedded(html_report, False)
 
-    def test_report_one_uuid_one_file(self):
+    def test_new_report_one_uuid_one_file(self):
         rally = utils.Rally()
         cfg = self._get_sample_task_config()
         config = utils.TaskConfig(cfg)
@@ -319,23 +297,22 @@ class TaskTestCase(unittest.TestCase):
         if os.path.exists(task_result_file):
             os.remove(task_result_file)
         rally("task results", report_path=task_result_file,
-              raw=True)
+              raw=True, no_logs=True)
 
         task_run_output = rally(
             "task start --task %s" % config.filename)
         task_uuid = self._get_task_uuid(task_run_output)
-        task_run_output = task_run_output.splitlines()
 
         html_report = rally.gen_report_path(extension="html")
-        rally("task report --tasks"
+        rally("task report --uuid"
               " %s %s --out %s" % (task_result_file, task_uuid,
-                                   html_report))
+                                   html_report), no_logs=True)
         self.assertTrue(os.path.exists(html_report))
         self.assertRaises(utils.RallyCliError,
                           rally, "task report --report %s" % FAKE_TASK_UUID)
         self._assert_html_report_libs_are_embedded(html_report, False)
 
-    def test_report_one_file_with_static_libs(self):
+    def test_new_report_one_file_with_static_libs(self):
         rally = utils.Rally()
         cfg = self._get_sample_task_config()
         config = utils.TaskConfig(cfg)
@@ -348,17 +325,7 @@ class TaskTestCase(unittest.TestCase):
 
         html_report = rally.gen_report_path(extension="html")
         rally("task report --html-static %s --out %s"
-              % (task_result_file, html_report))
-        self.assertTrue(os.path.exists(html_report))
-        self._assert_html_report_libs_are_embedded(html_report)
-
-    def test_report_one_uuid_with_static_libs(self):
-        rally = utils.Rally()
-        cfg = self._get_sample_task_config()
-        config = utils.TaskConfig(cfg)
-        rally("task start --task %s" % config.filename)
-        html_report = rally.gen_report_path(extension="html")
-        rally("task report --out %s --html-static" % html_report)
+              % (task_result_file, html_report), no_logs=True)
         self.assertTrue(os.path.exists(html_report))
         self._assert_html_report_libs_are_embedded(html_report)
 
@@ -368,7 +335,7 @@ class TaskTestCase(unittest.TestCase):
         config = utils.TaskConfig(cfg)
         rally("task start --task %s" % config.filename)
         html_report = rally.gen_report_path(extension="html")
-        rally("task report --out %s --html-static" % html_report)
+        rally("task report --out %s --html-static" % html_report, no_logs=True)
         self.assertTrue(os.path.exists(html_report))
         self._assert_html_report_libs_are_embedded(html_report)
 
@@ -386,7 +353,7 @@ class TaskTestCase(unittest.TestCase):
         config = utils.TaskConfig(cfg)
         rally("task start --task %s" % config.filename)
         json_report = rally.gen_report_path(extension="json")
-        rally("task report --out %s --json" % json_report)
+        rally("task report --out %s --json" % json_report, no_logs=True)
         self.assertTrue(os.path.exists(json_report))
         self._assert_json_report(json_report)
 
@@ -400,7 +367,7 @@ class TaskTestCase(unittest.TestCase):
             task_uuids.append(self._get_task_uuid(res))
         json_report = rally.gen_report_path(extension="json")
         rally("task report --json --uuid %s --out %s"
-              % (" ".join(task_uuids), json_report))
+              % (" ".join(task_uuids), json_report), no_logs=True)
         self.assertTrue(os.path.exists(json_report))
         self._assert_json_report(json_report)
 
@@ -456,11 +423,13 @@ class TaskTestCase(unittest.TestCase):
         rally("task start --task %s --tag trends_run run_once" %
               config2.filename)
 
-        tasks_list = rally("task list --uuids-only --tag trends_run")
+        tasks_list = rally("task list --uuids-only --tag trends_run",
+                           no_logs=True)
         uuids = [u for u in tasks_list.split("\n") if u]
 
         rally("task trends %(uuids)s --out %(report)s"
-              % {"uuids": " ".join(uuids), "report": report})
+              % {"uuids": " ".join(uuids), "report": report},
+              no_logs=True)
         del config1, config2
         self.assertTrue(os.path.exists(report))
 
@@ -629,7 +598,7 @@ class TaskTestCase(unittest.TestCase):
                "--deployment %(deployment_id)s --abort-on-sla-failure") %
               {"task_file": config.filename,
                "deployment_id": deployment_id})
-        results = json.loads(rally("task results"))
+        results = rally("task results", getjson=True)
         iterations_completed = len(results[0]["result"])
         self.assertEqual(times, iterations_completed)
 
@@ -699,11 +668,13 @@ class TaskTestCase(unittest.TestCase):
         rally = utils.Rally()
         deployment_id = utils.get_global("RALLY_DEPLOYMENT", rally.env)
         config = utils.TaskConfig(cfg)
-        rally(("task start --task %(task_file)s "
-               "--deployment %(deployment_id)s --abort-on-sla-failure") %
-              {"task_file": config.filename,
-               "deployment_id": deployment_id})
-        results = json.loads(rally("task results"))
+        self.assertRaises(utils.RallyCliError, rally,
+                          ("task start --task %(task_file)s "
+                           "--deployment %(deployment_id)s "
+                           "--abort-on-sla-failure") %
+                          {"task_file": config.filename,
+                           "deployment_id": deployment_id})
+        results = rally("task results", getjson=True)
         self.assertEqual(1, len(results),
                          "Second subtask should not be started")
         iterations_completed = len(results[0]["result"])
@@ -933,14 +904,14 @@ class TaskTestCase(unittest.TestCase):
             rally, cfg, "test_abort-thread_with_abort.txt")
         rally("task abort %s" % uuid)
         task.join()
-        results = json.loads(rally("task results"))
+        results = rally("task results", getjson=True)
         iterations_completed = len(results[0]["result"])
         # NOTE(msdubov): check that the task is really stopped before
         #                the specified number of iterations
         self.assertLess(iterations_completed, RUNNER_TIMES)
         self.assertIn("aborted", rally("task status"))
         report = rally.gen_report_path(extension="html")
-        rally("task report --out %s" % report)
+        rally("task report --out %s" % report, no_logs=True)
 
     def test_abort_soft(self):
         cfg = {
@@ -967,7 +938,7 @@ class TaskTestCase(unittest.TestCase):
             rally, cfg, "test_abort_soft-thread_with_soft_abort.txt")
         rally("task abort --soft")
         task.join()
-        results = json.loads(rally("task results"))
+        results = rally("task results", getjson=True)
         iterations_completed = len(results[0]["result"])
         self.assertEqual(3, iterations_completed)
         self.assertEqual(1, len(results))
@@ -1007,16 +978,18 @@ class TaskTestCase(unittest.TestCase):
         config = utils.TaskConfig(cfg)
         rally("task start --task %s" % config.filename)
         html_report = rally.gen_report_path(extension="html")
-        rally("task export --type html --to %s" % html_report)
+        rally("task export --type html --to %s" % html_report, no_logs=True)
         self.assertTrue(os.path.exists(html_report))
         self._assert_html_report_libs_are_embedded(html_report, False)
 
-        rally("task export --type html-static --to %s" % html_report)
+        rally("task export --type html-static --to %s" % html_report,
+              no_logs=True)
         self.assertTrue(os.path.exists(html_report))
         self._assert_html_report_libs_are_embedded(html_report)
 
         junit_report = rally.gen_report_path(extension="junit")
-        rally("task export --type junit-xml --to %s" % junit_report)
+        rally("task export --type junit-xml --to %s" % junit_report,
+              no_logs=True)
         self.assertTrue(os.path.exists(junit_report))
 
     def test_export_bunch_uuids(self):
@@ -1060,7 +1033,11 @@ class SLATestCase(unittest.TestCase):
         rally = utils.Rally()
         cfg = self._get_sample_task_config(max_seconds_per_iteration=0.001)
         config = utils.TaskConfig(cfg)
-        rally("task start --task %s" % config.filename)
+        with self.assertRaises(utils.RallyCliError) as err:
+            rally("task start --task %s" % config.filename)
+        output = err.exception.output
+        self.assertIn("At least one workload did not pass SLA criteria.",
+                      output)
         self.assertRaises(utils.RallyCliError, rally, "task sla-check")
 
     def test_sla_success(self):
@@ -1078,7 +1055,7 @@ class SLATestCase(unittest.TestCase):
              "detail": mock.ANY,
              "pos": 0, "status": "PASS"}
         ]
-        data = rally("task sla-check --json", getjson=True)
+        data = rally("task sla-check --json", getjson=True, no_logs=True)
         self.assertEqual(expected, data)
 
 
@@ -1101,7 +1078,9 @@ class SLAExtraFlagsTestCase(unittest.TestCase):
                 }
             ]}
         config = utils.TaskConfig(cfg)
-        rally("task start --task %s --abort-on-sla-failure" % config.filename)
+        self.assertRaises(utils.RallyCliError, rally,
+                          "task start --task %s --abort-on-sla-failure"
+                          % config.filename)
         expected = [
             {"benchmark": "Dummy.dummy_exception",
              "criterion": "aborted_on_sla",
@@ -1129,11 +1108,12 @@ class SLAExtraFlagsTestCase(unittest.TestCase):
                     "runner": runner,
                     "context": {
                         "dummy_context": {"fail_setup": True}
-                    }
+                    },
                 }
             ]}
         config = utils.TaskConfig(cfg)
-        rally("task start --task %s" % config.filename)
+        self.assertRaises(utils.RallyCliError, rally,
+                          "task start --task %s" % config.filename)
         expected = [
             {"status": "PASS",
              "benchmark": "Dummy.dummy",
@@ -1195,7 +1175,11 @@ class SLAPerfDegrTestCase(unittest.TestCase):
         rally = utils.Rally()
         cfg = self._get_sample_task_config(max_degradation=1)
         config = utils.TaskConfig(cfg)
-        rally("task start --task %s" % config.filename)
+        with self.assertRaises(utils.RallyCliError) as err:
+            rally("task start --task %s" % config.filename)
+        output = err.exception.output
+        self.assertIn("At least one workload did not pass SLA criteria.",
+                      output)
         self.assertRaises(utils.RallyCliError, rally, "task sla-check")
 
     def test_sla_success(self):
@@ -1290,12 +1274,12 @@ class HookTestCase(unittest.TestCase):
     def test_hook_result_with_constant_runner(self):
         rally = utils.Rally()
         cfg = self._get_sample_task_config(
-            cmd="/bin/true",
+            cmd="true",
             description="event_hook",
             runner={"constant": {"times": 10, "concurrency": 3}})
         config = utils.TaskConfig(cfg)
         rally("task start --task %s" % config.filename)
-        results = json.loads(rally("task results"))
+        results = rally("task results", getjson=True)
         hook_results = results[0]["hooks"]
         hooks_cfg = cfg["subtasks"][0]["hooks"]
         expected = [self._get_result(hooks_cfg[0], iterations=[5])]
@@ -1305,13 +1289,13 @@ class HookTestCase(unittest.TestCase):
     def test_hook_result_with_constant_for_duration_runner(self):
         rally = utils.Rally()
         cfg = self._get_sample_task_config(
-            cmd="/bin/true",
+            cmd="true",
             description="event_hook",
             runner={"constant_for_duration": {
                 "concurrency": 3, "duration": 10}})
         config = utils.TaskConfig(cfg)
         rally("task start --task %s" % config.filename)
-        results = json.loads(rally("task results"))
+        results = rally("task results", getjson=True)
         hook_results = results[0]["hooks"]
         hooks_cfg = cfg["subtasks"][0]["hooks"]
         expected = [self._get_result(hooks_cfg[0], iterations=[5])]
@@ -1321,12 +1305,12 @@ class HookTestCase(unittest.TestCase):
     def test_hook_result_with_rps_runner(self):
         rally = utils.Rally()
         cfg = self._get_sample_task_config(
-            cmd="/bin/true",
+            cmd="true",
             description="event_hook",
             runner={"rps": {"rps": 3, "times": 10}})
         config = utils.TaskConfig(cfg)
         rally("task start --task %s" % config.filename)
-        results = json.loads(rally("task results"))
+        results = rally("task results", getjson=True)
         hook_results = results[0]["hooks"]
         hooks_cfg = cfg["subtasks"][0]["hooks"]
         expected = [self._get_result(hooks_cfg[0], iterations=[5])]
@@ -1336,12 +1320,12 @@ class HookTestCase(unittest.TestCase):
     def test_hook_result_with_serial_runner(self):
         rally = utils.Rally()
         cfg = self._get_sample_task_config(
-            cmd="/bin/true",
+            cmd="true",
             description="event_hook",
             runner={"serial": {"times": 10}})
         config = utils.TaskConfig(cfg)
         rally("task start --task %s" % config.filename)
-        results = json.loads(rally("task results"))
+        results = rally("task results", getjson=True)
         hook_results = results[0]["hooks"]
         hooks_cfg = cfg["subtasks"][0]["hooks"]
         expected = [self._get_result(hooks_cfg[0], iterations=[5])]
@@ -1351,12 +1335,12 @@ class HookTestCase(unittest.TestCase):
     def test_hook_result_error(self):
         rally = utils.Rally()
         cfg = self._get_sample_task_config(
-            cmd="/bin/false",
+            cmd="false",
             description="event_hook",
             runner={"constant": {"times": 20, "concurrency": 3}})
         config = utils.TaskConfig(cfg)
         rally("task start --task %s" % config.filename)
-        results = json.loads(rally("task results"))
+        results = rally("task results", getjson=True)
         hook_results = results[0]["hooks"]
         hooks_cfg = cfg["subtasks"][0]["hooks"]
         expected = [self._get_result(hooks_cfg[0], iterations=[5], error=True)]
@@ -1366,29 +1350,29 @@ class HookTestCase(unittest.TestCase):
     def test_time_hook(self):
         rally = utils.Rally()
         cfg = self._get_sample_task_config(
-            cmd="/bin/true",
+            cmd="true",
             description="event_hook",
             runner={"constant_for_duration":
-                        {"concurrency": 3, "duration": 10}})
+                        {"concurrency": 3, "duration": 5}})
         cfg["subtasks"][0]["hooks"].append({
             "description": "time_hook",
-            "action": {"sys_call": "/bin/true"},
+            "action": {"sys_call": "true"},
             "trigger": {
                 "event": {
                     "unit": "time",
-                    "at": [3, 6, 9],
+                    "at": [1, 2, 3],
                 }
             }
         })
 
         config = utils.TaskConfig(cfg)
         rally("task start --task %s" % config.filename)
-        results = json.loads(rally("task results"))
+        results = rally("task results", getjson=True)
         hook_results = results[0]["hooks"]
 
         hooks_cfg = cfg["subtasks"][0]["hooks"]
         expected = [self._get_result(hooks_cfg[0], iterations=[5]),
-                    self._get_result(hooks_cfg[1], seconds=[3, 6, 9])]
+                    self._get_result(hooks_cfg[1], seconds=[1, 2, 3])]
         self.assertEqual(
             expected,
             sorted(hook_results,
@@ -1399,7 +1383,7 @@ class HookTestCase(unittest.TestCase):
     def test_import_hook_result(self):
         rally = utils.Rally()
         cfg = self._get_sample_task_config(
-            cmd="/bin/true",
+            cmd="true",
             description="event_hook",
             runner={"constant": {"times": 10, "concurrency": 3}})
         cfg["subtasks"][0]["hooks"].extend(
@@ -1430,9 +1414,8 @@ class HookTestCase(unittest.TestCase):
         rally("task start --task %s" % config.filename)
         json_report = rally.gen_report_path(extension="json")
         with open(json_report, "w+") as f:
-            f.write(rally("task results"))
+            f.write(rally("task results", no_logs=True))
         import_print = rally("task import --file %s" % json_report)
-        self.assertIn("successfully", import_print)
         task_uuid = re.search("UUID:\s([a-z0-9\-]+)", import_print).group(1)
         results = rally("task results --uuid %s" % task_uuid)
         self.assertIn("Dummy.dummy", results)
