@@ -37,28 +37,28 @@ class NetworkTestCase(test.TestCase):
     def test_START_CIDR_DFLT(self):
         netaddr.IPNetwork(network_context.Network.DEFAULT_CONFIG["start_cidr"])
 
-    @mock.patch("rally.osclients.Clients")
+    @mock.patch("rally.plugins.openstack.osclients.Clients")
     @mock.patch(NET + "wrap", return_value="foo_service")
     def test__init__default(self, mock_wrap, mock_clients):
         context = network_context.Network(self.get_context())
-        self.assertEqual(context.config["networks_per_tenant"], 1)
-        self.assertEqual(context.config["start_cidr"],
-                         network_context.Network.DEFAULT_CONFIG["start_cidr"])
+        self.assertEqual(1, context.config["networks_per_tenant"])
+        self.assertEqual(network_context.Network.DEFAULT_CONFIG["start_cidr"],
+                         context.config["start_cidr"])
         self.assertIsNone(context.config["dns_nameservers"])
 
-    @mock.patch("rally.osclients.Clients")
+    @mock.patch("rally.plugins.openstack.osclients.Clients")
     @mock.patch(NET + "wrap", return_value="foo_service")
     def test__init__explicit(self, mock_wrap, mock_clients):
         context = network_context.Network(
             self.get_context(start_cidr="foo_cidr", networks_per_tenant=42,
                              network_create_args={"fakearg": "fake"},
                              dns_nameservers=["1.2.3.4", "5.6.7.8"]))
-        self.assertEqual(context.config["networks_per_tenant"], 42)
-        self.assertEqual(context.config["start_cidr"], "foo_cidr")
-        self.assertEqual(context.config["network_create_args"],
-                         {"fakearg": "fake"})
-        self.assertEqual(context.config["dns_nameservers"],
-                         ("1.2.3.4", "5.6.7.8"))
+        self.assertEqual(42, context.config["networks_per_tenant"])
+        self.assertEqual("foo_cidr", context.config["start_cidr"])
+        self.assertEqual({"fakearg": "fake"},
+                         context.config["network_create_args"])
+        self.assertEqual(("1.2.3.4", "5.6.7.8"),
+                         context.config["dns_nameservers"])
 
     @ddt.data({},
               {"dns_nameservers": []},
@@ -66,7 +66,7 @@ class NetworkTestCase(test.TestCase):
     @ddt.unpack
     @mock.patch(NET + "wrap")
     @mock.patch("rally.plugins.openstack.context.network.networks.utils")
-    @mock.patch("rally.osclients.Clients")
+    @mock.patch("rally.plugins.openstack.osclients.Clients")
     def test_setup(self, mock_clients, mock_utils, mock_wrap, **dns_kwargs):
         mock_utils.iterate_per_tenants.return_value = [
             ("foo_user", "foo_tenant"),
@@ -86,8 +86,9 @@ class NetworkTestCase(test.TestCase):
             dns_kwargs["dns_nameservers"] = tuple(
                 dns_kwargs["dns_nameservers"])
         create_calls = [
-            mock.call(tenant, add_router=True,
+            mock.call(tenant,
                       subnets_num=1, network_create_args={"fakearg": "fake"},
+                      router_create_args={"external": True},
                       **dns_kwargs)
             for user, tenant in mock_utils.iterate_per_tenants.return_value]
         mock_create.assert_has_calls(create_calls)
@@ -102,7 +103,7 @@ class NetworkTestCase(test.TestCase):
         self.assertSequenceEqual(sorted(expected_networks),
                                  sorted(actual_networks))
 
-    @mock.patch("rally.osclients.Clients")
+    @mock.patch("rally.plugins.openstack.osclients.Clients")
     @mock.patch(NET + "wrap")
     def test_cleanup(self, mock_wrap, mock_clients):
         net_context = network_context.Network(self.get_context())
