@@ -15,8 +15,8 @@
 
 import ddt
 import mock
-from oslo_config import cfg
 
+from rally.common import cfg
 from rally import exceptions as rally_exceptions
 from rally.plugins.openstack.scenarios.nova import utils
 from tests.unit import fakes
@@ -649,11 +649,9 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
                                        "nova.detach_volume")
 
     def test__live_migrate_server(self):
-        fake_host = mock.MagicMock()
         self.admin_clients("nova").servers.get(return_value=self.server)
         nova_scenario = utils.NovaScenario(context=self.context)
         nova_scenario._live_migrate(self.server,
-                                    fake_host,
                                     block_migration=False,
                                     disk_over_commit=False,
                                     skip_host_check=True)
@@ -669,31 +667,6 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
                                        "nova.live_migrate")
 
-    def test__find_host_to_migrate(self):
-        fake_server = self.server
-        fake_host = {"nova-compute": {"available": True}}
-        fake_host_compute_off = {"nova-compute": {"available": False}}
-        fake_host_no_compute = {"nova-conductor": {"available": True}}
-        self.admin_clients("nova").servers.get.return_value = fake_server
-        self.admin_clients("nova").availability_zones.list.return_value = [
-            mock.MagicMock(zoneName="a",
-                           hosts={"a1": fake_host, "a2": fake_host,
-                                  "a3": fake_host}),
-            mock.MagicMock(zoneName="b",
-                           hosts={"b1": fake_host, "b2": fake_host,
-                                  "b3": fake_host, "b4": fake_host_compute_off,
-                                  "b5": fake_host_no_compute}),
-            mock.MagicMock(zoneName="c",
-                           hosts={"c1": fake_host,
-                                  "c2": fake_host, "c3": fake_host})
-        ]
-        setattr(fake_server, "OS-EXT-SRV-ATTR:host", "b2")
-        setattr(fake_server, "OS-EXT-AZ:availability_zone", "b")
-        nova_scenario = utils.NovaScenario(context=self.context)
-
-        self.assertIn(
-            nova_scenario._find_host_to_migrate(fake_server), ["b1", "b3"])
-
     def test__migrate_server(self):
         fake_server = self.server
         setattr(fake_server, "OS-EXT-SRV-ATTR:host", "a1")
@@ -803,7 +776,7 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
         self.admin_clients("nova").server_groups.list.assert_called_once_with(
             True)
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
-                                       "nova.list_server_groups")
+                                       "nova.list_server_groups", count=2)
 
     def test__delete_keypair(self):
         nova_scenario = utils.NovaScenario()
@@ -1095,7 +1068,7 @@ class NovaScenarioTestCase(test.ScenarioTestCase):
                                               description="desp")
 
         self._test_atomic_action_timer(nova_scenario.atomic_actions(),
-                                       "nova.update_server")
+                                       "nova.update_server", count=2)
 
     def test_create_aggregate(self):
         nova_scenario = utils.NovaScenario(context=self.context)
